==> qore-1.9.0.tar.bz2: qore-1.9.0/docs/modules/DataProvider/html/struct_data_provider_1_1_data_provider_summary_info.js <==
var struct_data_provider_1_1_data_provider_summary_info =
[
    [ "desc", "struct_data_provider_1_1_data_provider_summary_info.html#a3c494c63ed4cb6d5a134d952d26bf797", null ],
    [ "has_record", "struct_data_provider_1_1_data_provider_summary_info.html#a3fde284e4363d8e602e984e632f60980", null ],
    [ "name", "struct_data_provider_1_1_data_provider_summary_info.html#a2bd1c75c53f3e7d15f6b191dcf0f9162", null ],
    [ "supports_bulk_create", "struct_data_provider_1_1_data_provider_summary_info.html#a82033b60cc42ee126ab01c6ca948c960", null ],
    [ "supports_bulk_read", "struct_data_provider_1_1_data_provider_summary_info.html#aded83f07ee7cb5556fad99300ffe7a32", null ],
    [ "supports_bulk_upsert", "struct_data_provider_1_1_data_provider_summary_info.html#a093f221aaaa01f07fc82e192ccfe4bc0", null ],
    [ "supports_children", "struct_data_provider_1_1_data_provider_summary_info.html#a752c2b891206cb47f45a54a330253a7e", null ],
    [ "supports_create", "struct_data_provider_1_1_data_provider_summary_info.html#a1c5537aacfb3149c33e2992bdd2bcb02", null ],
    [ "supports_delete", "struct_data_provider_1_1_data_provider_summary_info.html#a9293127f93393acaa355ee1683e8bba4", null ],
    [ "supports_native_search", "struct_data_provider_1_1_data_provider_summary_info.html#ab5fdb71d67ba551cf098c167de98eff7", null ],
    [ "supports_read", "struct_data_provider_1_1_data_provider_summary_info.html#a386ee7b4e70af13f35be78642075623f", null ],
    [ "supports_request", "struct_data_provider_1_1_data_provider_summary_info.html#ab349b59dd05577c7650675d0c5808d37", null ],
    [ "supports_search_expressions", "struct_data_provider_1_1_data_provider_summary_info.html#ab3b14daaed5f9c74a2777eebb4915009", null ],
    [ "supports_update", "struct_data_provider_1_1_data_provider_summary_info.html#ad7676605916b472ecc0cbd72f9b7cb13", null ],
    [ "supports_upsert", "struct_data_provider_1_1_data_provider_summary_info.html#a6f5aee88ced96d78c2d5e89e05831522", null ],
    [ "transaction_management", "struct_data_provider_1_1_data_provider_summary_info.html#a0b8ddad3bb8af4f7e9c21d8af56e45a7", null ],
    [ "type", "struct_data_provider_1_1_data_provider_summary_info.html#ac442d8846d619802fc28a3972b9d3e65", null ]
];

==> qore-1.10.0.tar.bz2: qore-1.10.0/docs/modules/DataProvider/html/struct_data_provider_1_1_data_provider_summary_info.js <==
var struct_data_provider_1_1_data_provider_summary_info =
[
    [ "desc", "struct_data_provider_1_1_data_provider_summary_info.html#a3c494c63ed4cb6d5a134d952d26bf797", null ],
    [ "has_record", "struct_data_provider_1_1_data_provider_summary_info.html#a3fde284e4363d8e602e984e632f60980", null ],
    [ "name", "struct_data_provider_1_1_data_provider_summary_info.html#a2bd1c75c53f3e7d15f6b191dcf0f9162", null ],
    [ "supports_bulk_create", "struct_data_provider_1_1_data_provider_summary_info.html#a82033b60cc42ee126ab01c6ca948c960", null ],
    [ "supports_bulk_read", "struct_data_provider_1_1_data_provider_summary_info.html#aded83f07ee7cb5556fad99300ffe7a32", null ],
    [ "supports_bulk_upsert", "struct_data_provider_1_1_data_provider_summary_info.html#a093f221aaaa01f07fc82e192ccfe4bc0", null ],
    [ "supports_children", "struct_data_provider_1_1_data_provider_summary_info.html#a752c2b891206cb47f45a54a330253a7e", null ],
    [ "supports_create", "struct_data_provider_1_1_data_provider_summary_info.html#a1c5537aacfb3149c33e2992bdd2bcb02", null ],
    [ "supports_delete", "struct_data_provider_1_1_data_provider_summary_info.html#a9293127f93393acaa355ee1683e8bba4", null ],
    [ "supports_messages", "struct_data_provider_1_1_data_provider_summary_info.html#abfa58a717f271e7a973f178b41bf0bd2", null ],
    [ "supports_native_search", "struct_data_provider_1_1_data_provider_summary_info.html#ab5fdb71d67ba551cf098c167de98eff7", null ],
    [ "supports_observable", "struct_data_provider_1_1_data_provider_summary_info.html#a05336ea6d6cd8d8328cff560b1c2641c", null ],
    [ "supports_read", "struct_data_provider_1_1_data_provider_summary_info.html#a386ee7b4e70af13f35be78642075623f", null ],
    [ "supports_request", "struct_data_provider_1_1_data_provider_summary_info.html#ab349b59dd05577c7650675d0c5808d37", null ],
    [ "supports_search_expressions", "struct_data_provider_1_1_data_provider_summary_info.html#ab3b14daaed5f9c74a2777eebb4915009", null ],
    [ "supports_update", "struct_data_provider_1_1_data_provider_summary_info.html#ad7676605916b472ecc0cbd72f9b7cb13", null ],
    [ "supports_upsert", "struct_data_provider_1_1_data_provider_summary_info.html#a6f5aee88ced96d78c2d5e89e05831522", null ],
    [ "transaction_management", "struct_data_provider_1_1_data_provider_summary_info.html#a0b8ddad3bb8af4f7e9c21d8af56e45a7", null ],
    [ "type", "struct_data_provider_1_1_data_provider_summary_info.html#ac442d8846d619802fc28a3972b9d3e65", null ]
];
